@@ -23,11 +23,11 @@
 
 #include "svnfrontend/svnactions.h"
 #include "svnfrontend/dummydisplay.h"
-#include "svncpp/dirent.hpp"
-#include "svncpp/url.hpp"
-#include "svncpp/status.hpp"
-#include "svncpp/targets.hpp"
-#include "svncpp/info_entry.hpp"
+#include "svnqt/dirent.hpp"
+#include "svnqt/url.hpp"
+#include "svnqt/status.hpp"
+#include "svnqt/targets.hpp"
+#include "svnqt/info_entry.hpp"
 #include "helpers/sub2qt.h"
 
 #include <stdlib.h>
@@ -72,7 +72,7 @@ public:
     KioListener m_Listener;
     bool first_done;
     svn::Context* m_CurrentContext;
-    svn::Client m_Svnclient;
+    svn::Client* m_Svnclient;
 
     svn::Revision urlToRev(const KURL&);
 
@@ -81,6 +81,7 @@ public:
 KioSvnData::KioSvnData(kio_svnProtocol*par)
     : m_Listener(par),first_done(false)
 {
+    m_Svnclient=svn::Client::getobject(0,0);
     m_CurrentContext = 0;
     reInitClient();
 }
@@ -94,11 +95,12 @@ void KioSvnData::reInitClient()
     delete m_CurrentContext;
     m_CurrentContext = new svn::Context();
     m_CurrentContext->setListener(&m_Listener);
-    m_Svnclient.setContext(m_CurrentContext);
+    m_Svnclient->setContext(m_CurrentContext);
 }
 
 KioSvnData::~KioSvnData()
 {
+    delete m_Svnclient;
     delete m_CurrentContext;
 }
 
@@ -109,7 +111,7 @@ svn::Revision KioSvnData::urlToRev(const KURL&url)
     rev = svn::Revision::UNDEFINED;
     if (q.find("rev")!=q.end()) {
         QString v = q["rev"];
-        m_Svnclient.url2Revision(v,rev,tmp);
+        m_Svnclient->url2Revision(v,rev,tmp);
     }
     return rev;
 }
@@ -165,7 +167,6 @@ int kdemain(int argc, char **argv)
 void kio_svnProtocol::listDir(const KURL&url)
 {
     kdDebug() << "kio_svn::listDir(const KURL& url) : " << url.url() << endl ;
-    //m_pData->reInitClient();
     svn::DirEntries dlist;
     svn::Revision rev = m_pData->urlToRev(url);
     if (rev == svn::Revision::UNDEFINED) {
@@ -173,7 +174,7 @@ void kio_svnProtocol::listDir(const KURL&url)
     }
 
     try {
-        dlist = m_pData->m_Svnclient.list(makeSvnUrl(url),rev,false);
+        dlist = m_pData->m_Svnclient->list(makeSvnUrl(url),rev,rev,false,false);
     } catch (svn::ClientException e) {
         QString ex = e.msg();
         kdDebug()<<ex<<endl;
@@ -201,16 +202,15 @@ void kio_svnProtocol::listDir(const KURL&url)
 void kio_svnProtocol::stat(const KURL& url)
 {
     kdDebug()<<"kio_svn::stat "<< url << endl;
-    //m_pData->reInitClient();
     svn::Revision rev = m_pData->urlToRev(url);
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
     }
-    svn::Revision peg = svn::Revision::UNDEFINED;
+    svn::Revision peg = rev;
     QString s = makeSvnUrl(url);
     svn::InfoEntries e;
     try {
-        e = m_pData->m_Svnclient.info(s,false,rev,peg);
+        e = m_pData->m_Svnclient->info(s,false,rev,peg);
     } catch  (svn::ClientException e) {
         QString ex = e.msg();
         kdDebug()<<ex<<endl;
@@ -237,14 +237,13 @@ void kio_svnProtocol::stat(const KURL& url)
 void kio_svnProtocol::get(const KURL& url)
 {
     kdDebug()<<"kio_svn::get "<< url << endl;
-    //m_pData->reInitClient();
     svn::Revision rev = m_pData->urlToRev(url);
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
     }
     QByteArray content;
     try {
-        content = m_pData->m_Svnclient.cat(makeSvnUrl(url),rev);
+        content = m_pData->m_Svnclient->cat(makeSvnUrl(url),rev,rev);
     } catch (svn::ClientException e) {
         QString ex = e.msg();
         kdDebug()<<ex<<endl;
@@ -271,15 +270,11 @@ void kio_svnProtocol::mkdir(const KURL &url, int)
         rev = svn::Revision::HEAD;
     }
     QString msg;
-    if (!getLogMsg(msg)) {
-        error(KIO::ERR_COULD_NOT_MKDIR,url.prettyURL());
-    } else {
-        svn::Path p(makeSvnUrl(url));
-        try {
-            m_pData->m_Svnclient.mkdir(p,msg);
-        }catch (svn::ClientException e) {
-            error( KIO::ERR_SLAVE_DEFINED,e.msg());
-        }
+    svn::Path p(makeSvnUrl(url));
+    try {
+        m_pData->m_Svnclient->mkdir(p,msg);
+    }catch (svn::ClientException e) {
+        error( KIO::ERR_SLAVE_DEFINED,e.msg());
     }
     kdDebug()<<"kio_svn::get finished " << url << endl;
     finished();
@@ -288,14 +283,9 @@ void kio_svnProtocol::mkdir(const KURL &url, int)
 void kio_svnProtocol::rename(const KURL&src,const KURL&target,bool force)
 {
     kdDebug()<<"kio_svn::rename "<< src << " to " << target <<  endl;
-    //m_pData->reInitClient();
-    svn::Revision rev = m_pData->urlToRev(src);
-    if (rev == svn::Revision::UNDEFINED) {
-        rev = svn::Revision::HEAD;
-    }
     QString msg;
     try {
-        m_pData->m_Svnclient.move(makeSvnUrl(src),rev,makeSvnUrl(target),force);
+        m_pData->m_Svnclient->move(makeSvnUrl(src),makeSvnUrl(target),force);
     }catch (svn::ClientException e) {
         error( KIO::ERR_SLAVE_DEFINED,e.msg());
     }
@@ -306,14 +296,13 @@ void kio_svnProtocol::rename(const KURL&src,const KURL&target,bool force)
 void kio_svnProtocol::copy(const KURL&src,const KURL&dest,int permissions,bool overwrite)
 {
     kdDebug()<<"kio_svn::copy "<< src << " to " << dest <<  endl;
-    //m_pData->reInitClient();
     svn::Revision rev = m_pData->urlToRev(src);
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
     }
     QString msg;
     try {
-        m_pData->m_Svnclient.copy(makeSvnUrl(src),rev,makeSvnUrl(dest));
+        m_pData->m_Svnclient->copy(makeSvnUrl(src),rev,makeSvnUrl(dest));
     }catch (svn::ClientException e) {
         error( KIO::ERR_SLAVE_DEFINED,e.msg());
     }
@@ -331,7 +320,7 @@ void kio_svnProtocol::del(const KURL&src,bool isfile)
     }
     svn::Targets target(makeSvnUrl(src));
     try {
-        m_pData->m_Svnclient.remove(target,false);
+        m_pData->m_Svnclient->remove(target,false);
     } catch (svn::ClientException e) {
         QString ex = e.msg();
         kdDebug()<<ex<<endl;
@@ -343,27 +332,24 @@ void kio_svnProtocol::del(const KURL&src,bool isfile)
 
 bool kio_svnProtocol::getLogMsg(QString&t)
 {
-    return m_pData->m_Listener.contextGetLogMessage(t);
+    svn::CommitItemList _items;
+    return m_pData->m_Listener.contextGetLogMessage(t,_items);
 }
 
 QString kio_svnProtocol::makeSvnUrl(const KURL&url)
 {
     QString res;
     QString proto = svn::Url::transformProtokoll(url.protocol());
-    KURL _url = url;
-    _url.cleanPath(true);
-    _url.setProtocol(proto);
-    if (proto=="file") {
-        res = proto+"://"+url.path();
+
+    QStringList s = QStringList::split("://",res);
+    QString base = url.path();
+    QString host = url.host();
+    if (host.isEmpty()) {
+        res=proto+"://"+base;
     } else {
-        res = _url.url(-1);
+        res = proto+"://"+host+base;
     }
-    QStringList s = QStringList::split("?",res);
-    if (s.size()>1) {
-        res = s[0];
-    }
-    svn::Path t(res);
-    return t.path();
+    return res;
 }
 
 bool kio_svnProtocol::createUDSEntry( const QString& filename, const QString& user, long long int size, bool isdir, time_t mtime, KIO::UDSEntry& entry)
@@ -537,7 +523,7 @@ void kio_svnProtocol::update(const KURL&url,int revnumber,const QString&revkind)
         svn::Targets pathes(p.path());
         // recursive second last parameter
         // always update externals, too. (last parameter)
-        m_pData->m_Svnclient.update(pathes, where,true,false);
+        m_pData->m_Svnclient->update(pathes, where,true,false);
     } catch (svn::ClientException e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
@@ -549,7 +535,7 @@ void kio_svnProtocol::status(const KURL&wc,bool cR,bool rec)
     svn::StatusEntries dlist;
     try {
         //                                            rec all  up     noign
-        dlist = m_pData->m_Svnclient.status(wc.path(),rec,false,cR,false,where);
+        dlist = m_pData->m_Svnclient->status(wc.path(),rec,false,cR,false,where);
     } catch (svn::ClientException e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
@@ -604,7 +590,7 @@ void kio_svnProtocol::commit(const KURL::List&url)
     }
     svn_revnum_t nnum=svn::Revision::UNDEFINED;
     try {
-        nnum = m_pData->m_Svnclient.commit(svn::Targets(targets),msg,true);
+        nnum = m_pData->m_Svnclient->commit(svn::Targets(targets),msg,true);
     } catch (svn::ClientException e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
@@ -628,10 +614,11 @@ void kio_svnProtocol::commit(const KURL::List&url)
 void kio_svnProtocol::checkout(const KURL&src,const KURL&target,const int rev, const QString&revstring)
 {
     svn::Revision where(rev,revstring);
+    svn::Revision peg = svn::Revision::UNDEFINED;
     KURL _src = makeSvnUrl(src);
     svn::Path _target(target.path());
     try {
-        m_pData->m_Svnclient.checkout(_src.url(),_target,where,false);
+        m_pData->m_Svnclient->checkout(_src.url(),_target,where,peg,true,false);
     } catch (svn::ClientException e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
@@ -646,7 +633,7 @@ void kio_svnProtocol::svnlog(int revstart,const QString&revstringstart,int reven
     for (unsigned j = 0; j<urls.count();++j) {
         logs = 0;
         try {
-            logs = m_pData->m_Svnclient.log(makeSvnUrl(urls[j]),start,end,true,true,0);
+            logs = m_pData->m_Svnclient->log(makeSvnUrl(urls[j]),start,end,true,true,0);
         } catch (svn::ClientException e) {
             error(KIO::ERR_SLAVE_DEFINED,e.msg());
             break;
@@ -694,7 +681,7 @@ void kio_svnProtocol::revert(const KURL::List&l)
     }
     svn::Targets target(list);
     try {
-        m_pData->m_Svnclient.revert(target,false);
+        m_pData->m_Svnclient->revert(target,false);
     } catch (svn::ClientException e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
@@ -705,7 +692,7 @@ void kio_svnProtocol::wc_switch(const KURL&wc,const KURL&target,bool rec,int rev
     svn::Revision where(rev,revstring);
     svn::Path wc_path(wc.path());
     try {
-        m_pData->m_Svnclient.doSwitch(wc_path,makeSvnUrl(target.url()),where,rec);
+        m_pData->m_Svnclient->doSwitch(wc_path,makeSvnUrl(target.url()),where,rec);
     } catch (svn::ClientException e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
@@ -721,9 +708,10 @@ void kio_svnProtocol::diff(const KURL&uri1,const KURL&uri2,int rnum1,const QStri
     QString ex = "";
     KTempDir tdir;
     tdir.setAutoDelete(true);
+    /// @todo read settings for diff (ignore contentype)
     try {
-        ex = m_pData->m_Svnclient.diff(svn::Path(tdir.name()),
-        u1,u2,r1, r2,rec,false,false);
+        ex = m_pData->m_Svnclient->diff(svn::Path(tdir.name()),
+        u1,u2,r1, r2,rec,false,false,false);
     } catch (svn::ClientException e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
