@@ -21,9 +21,9 @@
 #include "fronthelpers/settings.h"
 #include "svnfrontend/svnactions.h"
 #include "svnfrontend/dummydisplay.h"
-#include "svncpp/targets.hpp"
-#include "svncpp/url.hpp"
-#include "svncpp/dirent.hpp"
+#include "svnqt/targets.hpp"
+#include "svnqt/url.hpp"
+#include "svnqt/dirent.hpp"
 #include "helpers/sub2qt.h"
 #include "helpers/ktranslateurl.h"
 #include "svnfrontend/fronthelpers/rangeinput_impl.h"
@@ -234,10 +234,15 @@ int CommandExec::exec()
                 tmp = tmpurl.path();
             }
         }
+        QStringList l = QStringList::split('?',tmp);
+        if (l.count()>0) {
+            tmp=l[0];
+        }
         while (tmp.endsWith("/")) {
             tmp.truncate(tmp.length()-1);
         }
         m_pCPart->url.append(tmp);
+        kdDebug()<<"Resulting url: "<<tmp<<endl;
         if ( (j>2 && dont_check_second) || dont_check_all) {
             continue;
         }
@@ -345,7 +350,10 @@ void CommandExec::slotCmd_cat()
         m_pCPart->end = svn::Revision::HEAD;
         kdDebug()<<"Setting head standard for cat"<<endl;
     }
-    m_pCPart->m_SvnWrapper->makeCat((m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),m_pCPart->url[0],m_pCPart->url[0]);
+    kdDebug()<<"Rev set "<<m_pCPart->rev_set<<endl;
+    m_pCPart->m_SvnWrapper->makeCat(
+        (m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),m_pCPart->url[0],m_pCPart->url[0]
+        ,(m_pCPart->rev_set?m_pCPart->start:m_pCPart->end));
 }
 
 void CommandExec::slotCmd_get()
@@ -366,7 +374,8 @@ void CommandExec::slotCmd_get()
         clientException(i18n("Could not open %1 for writing").arg(m_pCPart->outfile));
         return;
     }
-    QByteArray content = m_pCPart->m_SvnWrapper->makeGet((m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),m_pCPart->url[0]);
+    QByteArray content = m_pCPart->m_SvnWrapper->makeGet((m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),m_pCPart->url[0]
+        ,(m_pCPart->rev_set?m_pCPart->start:m_pCPart->end));
     if (!content.size()||of.writeBlock(content,content.size())==-1) {
         clientException(i18n("Error getting content and/or writing it to %1").arg(m_pCPart->outfile));
     }
@@ -437,33 +446,44 @@ void CommandExec::slotCmd_list()
     }
 }
 
-void CommandExec::copy_move(const QString&source,bool _move)
-{
-    bool ok,force;
-    QString target = CopyMoveView_impl::getMoveCopyTo(&ok,&force,_move,
-        source,"",0,"move_name");
-    if (!ok) {
-        return;
-    }
-    m_pCPart->m_SvnWrapper->slotCopyMove(_move,source,target,force);
-}
-
 void CommandExec::slotCmd_copy()
 {
+    QString target;
     if (m_pCPart->url.count()<2) {
-        copy_move(m_pCPart->url[0],false);
-        return;
+        bool force_move,ok;
+        target = CopyMoveView_impl::getMoveCopyTo(&ok,&force_move,false,
+            m_pCPart->url[0],"",0,"move_name");
+        if (!ok) {
+            return;
+        }
+    } else {
+        target = m_pCPart->url[1];
     }
-    m_pCPart->m_SvnWrapper->slotCopyMove(false,m_pCPart->url[0],m_pCPart->url[1],false);
+    if (m_pCPart->extraRevisions.find(0)!=m_pCPart->extraRevisions.end()) {
+        m_pCPart->rev_set=true;
+        m_pCPart->start=m_pCPart->extraRevisions[0];
+    } else {
+        m_pCPart->end = svn::Revision::HEAD;
+        kdDebug()<<"Setting head standard for copy"<<endl;
+    }
+    m_pCPart->m_SvnWrapper->makeCopy(m_pCPart->url[0],target,(m_pCPart->rev_set?m_pCPart->start:m_pCPart->end));
 }
 
 void CommandExec::slotCmd_move()
 {
+    bool force_move,ok;
+    force_move = false;
+    QString target;
     if (m_pCPart->url.count()<2) {
-        copy_move(m_pCPart->url[0],true);
-        return;
+        target = CopyMoveView_impl::getMoveCopyTo(&ok,&force_move,true,
+            m_pCPart->url[0],"",0,"move_name");
+        if (!ok) {
+            return;
+        }
+    } else {
+        target = m_pCPart->url[1];
     }
-    m_pCPart->m_SvnWrapper->slotCopyMove(true,m_pCPart->url[0],m_pCPart->url[1],false);
+    m_pCPart->m_SvnWrapper->makeMove(m_pCPart->url[0],target,force_move);
 }
 
 void CommandExec::slotCmd_delete()
