@@ -29,12 +29,13 @@
 #include "keystatus.h"
 #include "checkoutinfo_impl.h"
 #include "fronthelpers/settings.h"
-#include "svncpp/revision.hpp"
-#include "svncpp/dirent.hpp"
-#include "svncpp/client.hpp"
-#include "svncpp/status.hpp"
-#include "svncpp/url.hpp"
+#include "svnqt/revision.hpp"
+#include "svnqt/dirent.hpp"
+#include "svnqt/client.hpp"
+#include "svnqt/status.hpp"
+#include "svnqt/url.hpp"
 #include "helpers/sshagent.h"
+#include "helpers/sub2qt.h"
 
 #include <kapplication.h>
 #include <kiconloader.h>
@@ -167,18 +168,24 @@ kdesvnfilelist::kdesvnfilelist(KActionCollection*aCollect,QWidget *parent, const
     setupActions();
 
     connect(this,SIGNAL(clicked(QListViewItem*)),this,SLOT(slotItemClicked(QListViewItem*)));
-    connect(this,SIGNAL(rightButtonPressed(QListViewItem *, const QPoint &, int)),this,
-        SLOT(slotRightButton(QListViewItem *, const QPoint &, int)));
+    connect(this,SIGNAL(contextMenuRequested(QListViewItem *, const QPoint &, int)),this,
+        SLOT(slotContextMenuRequested(QListViewItem *, const QPoint &, int)));
+
+    /* not via executed 'cause click may used for selection - single click execution
+       just confuses in an application */
     connect(this,SIGNAL(doubleClicked(QListViewItem*)),this,SLOT(slotItemDoubleClicked(QListViewItem*)));
+    connect(this,SIGNAL(returnPressed(QListViewItem*)),this,SLOT(slotItemDoubleClicked(QListViewItem*)));
+
     connect(this,SIGNAL(selectionChanged()),this,SLOT(slotSelectionChanged()));
     connect(m_SvnWrapper,SIGNAL(clientException(const QString&)),this,SLOT(slotClientException(const QString&)));
     connect(m_SvnWrapper,SIGNAL(sendNotify(const QString&)),this,SLOT(slotNotifyMessage(const QString&)));
     connect(m_SvnWrapper,SIGNAL(reinitItem(SvnItem*)),this,SLOT(slotReinitItem(SvnItem*)));
     connect(m_SvnWrapper,SIGNAL(sigRefreshAll()),this,SLOT(refreshCurrentTree()));
     connect(m_SvnWrapper,SIGNAL(sigRefreshCurrent(SvnItem*)),this,SLOT(refreshCurrent(SvnItem*)));
-    connect(m_SvnWrapper,SIGNAL(sigRefreshIcons()),this,SLOT(slotRescanIcons()));
+    connect(m_SvnWrapper,SIGNAL(sigRefreshIcons(bool)),this,SLOT(slotRescanIcons(bool)));
     connect(this,SIGNAL(dropped (QDropEvent*,QListViewItem*)),
             this,SLOT(slotDropped(QDropEvent*,QListViewItem*)));
+    connect(m_SvnWrapper,SIGNAL(sigGotourl(const QString&)),this,SLOT(_openURL(const QString&)));
 
     setDropHighlighter(true);
     setDragEnabled(true);
@@ -198,8 +205,10 @@ void kdesvnfilelist::setupActions()
     KAction*tmp_action;
     /* local and remote actions */
     /* 1. actions on dirs AND files */
-    m_LogRangeAction = new KAction(i18n("&Log..."),"kdesvnlog",KShortcut(SHIFT+CTRL+Key_L),this,SLOT(slotMakeRangeLog()),m_filesAction,"make_svn_log");
-    m_LogFullAction = new KAction(i18n("&Full Log"),"kdesvnlog",KShortcut(CTRL+Key_L),this,SLOT(slotMakeLog()),m_filesAction,"make_svn_log_full");
+    m_LogRangeAction = new KAction(i18n("Log..."),"kdesvnlog",KShortcut(SHIFT+CTRL+Key_L),this,SLOT(slotMakeRangeLog()),m_filesAction,"make_svn_log");
+    m_LogFullAction = new KAction(i18n("Full Log"),"kdesvnlog",KShortcut(CTRL+Key_L),this,SLOT(slotMakeLog()),m_filesAction,"make_svn_log_full");
+    tmp_action = new KAction(i18n("Full revision tree"),"kdesvnlog",KShortcut(CTRL+Key_T),this,SLOT(slotMakeTree()),m_filesAction,"make_svn_tree");
+
     m_propertyAction = new KAction(i18n("Properties"),"edit",
         KShortcut(Key_P),m_SvnWrapper,SLOT(slotProperties()),m_filesAction,"make_svn_property");
     m_InfoAction = new KAction(i18n("Details"),"kdesvninfo",
@@ -212,24 +221,29 @@ void kdesvnfilelist::setupActions()
     tmp_action->setToolTip(i18n("Check if current working copy has items with newer version in repository"));
 
     /* 2. actions only on files */
-    m_BlameAction = new KAction("&Blame","kdesvnblame",KShortcut(),this,SLOT(slotBlame()),m_filesAction,"make_svn_blame");
+    m_BlameAction = new KAction(i18n("Blame"),"kdesvnblame",
+        KShortcut(),this,SLOT(slotBlame()),m_filesAction,"make_svn_blame");
     m_BlameAction->setToolTip(i18n("Output the content of specified files or URLs with revision and author information in-line."));
-    m_BlameRangeAction = new KAction("Blame range","kdesvnblame",KShortcut(),this,SLOT(slotRangeBlame()),m_filesAction,"make_svn_range_blame");
+    m_BlameRangeAction = new KAction(i18n("Blame range"),"kdesvnblame",
+        KShortcut(),this,SLOT(slotRangeBlame()),m_filesAction,"make_svn_range_blame");
     m_BlameRangeAction->setToolTip(i18n("Output the content of specified files or URLs with revision and author information in-line."));
-    m_CatAction = new KAction(i18n("Cat head"),
-        "kdesvncat",KShortcut(),this,SLOT(slotCat()),m_filesAction,"make_svn_cat");
+    m_CatAction = new KAction(i18n("Cat head"), "kdesvncat",
+        KShortcut(),this,SLOT(slotCat()),m_filesAction,"make_svn_cat");
     m_CatAction->setToolTip(i18n("Output the content of specified files or URLs."));
-    tmp_action = new KAction(i18n("Cat revision..."),"kdesvncat",KShortcut(),this,SLOT(slotRevisionCat()),m_filesAction,"make_revisions_cat");
+    tmp_action = new KAction(i18n("Cat revision..."),"kdesvncat",
+        KShortcut(),this,SLOT(slotRevisionCat()),m_filesAction,"make_revisions_cat");
     tmp_action->setToolTip(i18n("Output the content of specified files or URLs at specific revision."));
 
-    m_LockAction = new KAction(i18n("Lock current items"),"kdesvnlock",KShortcut(),this,SLOT(slotLock()),m_filesAction,"make_svn_lock");
-    m_UnlockAction = new KAction(i18n("Unlock current items"),"kdesvnunlock",KShortcut(),this,SLOT(slotUnlock()),m_filesAction,"make_svn_unlock");
+    m_LockAction = new KAction(i18n("Lock current items"),"kdesvnlock",
+        KShortcut(),this,SLOT(slotLock()),m_filesAction,"make_svn_lock");
+    m_UnlockAction = new KAction(i18n("Unlock current items"),"kdesvnunlock",
+        KShortcut(),this,SLOT(slotUnlock()),m_filesAction,"make_svn_unlock");
 
     /* 3. actions only on dirs */
-    m_MkdirAction = new KAction("New folder","folder_new",
+    m_MkdirAction = new KAction(i18n("New folder"),"folder_new",
         KShortcut(),this,SLOT(slotMkdir()),m_filesAction,"make_svn_mkdir");
-    m_switchRepository = new KAction("Switch repository","kdesvnswitch",KShortcut(),
-        m_SvnWrapper,SLOT(slotSwitch()),m_filesAction,"make_svn_switch");
+    m_switchRepository = new KAction(i18n("Switch repository"),"kdesvnswitch",
+        KShortcut(), m_SvnWrapper,SLOT(slotSwitch()),m_filesAction,"make_svn_switch");
     m_switchRepository->setToolTip(i18n("Switch repository path of current working copy path (\"svn switch\")"));
     tmp_action = new KAction(i18n("Relocate current working copy url"),"kdesvnrelocate",KShortcut(),
         this,SLOT(slotRelocate()),m_filesAction,"make_svn_relocate");
@@ -242,36 +256,36 @@ void kdesvnfilelist::setupActions()
         this,SLOT(slotChangeToRepository()),m_filesAction,"make_switch_to_repo");
     m_changeToRepository->setToolTip(i18n("Opens the repository the current working copy was checked out from"));
 
-    m_CleanupAction = new KAction("Cleanup","kdesvncleanup",KShortcut(),
-        this,SLOT(slotCleanupAction()),m_filesAction,"make_cleanup");
+    m_CleanupAction = new KAction(i18n("Cleanup"),"kdesvncleanup",
+	KShortcut(),this,SLOT(slotCleanupAction()),m_filesAction,"make_cleanup");
     m_ImportDirsIntoCurrent  = new KAction(i18n("Import folders into current"),"fileimport",KShortcut(),
         this,SLOT(slotImportDirsIntoCurrent()),m_filesAction,"make_import_dirs_into_current");
     m_ImportDirsIntoCurrent->setToolTip(i18n("Import folder content into current url"));
 
     /* local only actions */
     /* 1. actions on files AND dirs*/
-    m_AddCurrent = new KAction("Add selected files/dirs",
+    m_AddCurrent = new KAction(i18n("Add selected files/dirs"),
         "kdesvnadd",KShortcut(Key_Insert),m_SvnWrapper,SLOT(slotAdd()),m_filesAction,"make_svn_add");
     m_AddCurrent->setToolTip(i18n("Adding selected files and/or directories to repository"));
     tmp_action = new KAction("Add selected files/dirs recursive",
         "kdesvnaddrecursive",KShortcut(CTRL+Key_Insert),m_SvnWrapper,SLOT(slotAddRec()),m_filesAction,"make_svn_addrec");
     tmp_action->setToolTip(i18n("Adding selected files and/or directories to repository and all subitems of folders"));
 
-    m_DelCurrent = new KAction("Delete selected files/dirs","kdesvndelete",
+    m_DelCurrent = new KAction(i18n("Delete selected files/dirs"),"kdesvndelete",
         KShortcut(Key_Delete),this,SLOT(slotDelete()),m_filesAction,"make_svn_remove");
     m_DelCurrent->setToolTip(i18n("Deleting selected files and/or directories from repository"));
-    m_RevertAction  = new KAction("Revert current changes","revert",
+    m_RevertAction  = new KAction(i18n("Revert current changes"),"revert",
         KShortcut(),m_SvnWrapper,SLOT(slotRevert()),m_filesAction,"make_svn_revert");
-    m_ResolvedAction = new KAction("Resolve recursive",KShortcut(),
+    m_ResolvedAction = new KAction(i18n("Resolve recursive"),KShortcut(),
         this,SLOT(slotResolved()),m_filesAction,"make_resolved");
     m_ResolvedAction->setToolTip(i18n("Marking files or dirs resolved"));
     m_IgnoreAction = new KAction(i18n("Ignore/Unignore current item"),KShortcut(),this,SLOT(slotIgnore()),m_filesAction,"make_svn_ignore");
 
-    m_UpdateHead = new KAction("Update to head","kdesvnupdate",
+    m_UpdateHead = new KAction(i18n("Update to head"),"kdesvnupdate",
         KShortcut(),m_SvnWrapper,SLOT(slotUpdateHeadRec()),m_filesAction,"make_svn_headupdate");
-    m_UpdateRev = new KAction("Update to revision...","kdesvnupdate",
+    m_UpdateRev = new KAction(i18n("Update to revision..."),"kdesvnupdate",
         KShortcut(),m_SvnWrapper,SLOT(slotUpdateTo()),m_filesAction,"make_svn_revupdate");
-    m_commitAction = new KAction("Commit","kdesvncommit",
+    m_commitAction = new KAction(i18n("Commit"),"kdesvncommit",
         KShortcut("#"),m_SvnWrapper,SLOT(slotCommit()),m_filesAction,"make_svn_commit");
 
     m_simpleDiffHead = new KAction(i18n("Diff local changes"),"kdesvndiff",
@@ -287,8 +301,12 @@ void kdesvnfilelist::setupActions()
         KShortcut(),this,SLOT(slotMergeRevisions()),m_filesAction,"make_svn_merge_revisions");
     m_MergeRevisionAction->setToolTip(i18n("Merge two revisions of these entry into itself"));
 
+    tmp_action=new KAction(i18n("Merge..."),"kdesvnmerge",
+        KShortcut(),this,SLOT(slotMerge()),m_filesAction,"make_svn_merge");
+    tmp_action->setToolTip("Merge repository path into current worky copy path or current repository path into a target");
+
     /* remote actions only */
-    m_CheckoutCurrentAction = new KAction("Checkout current repository path","kdesvncheckout",KShortcut(),
+    m_CheckoutCurrentAction = new KAction(i18n("Checkout current repository path"),"kdesvncheckout",KShortcut(),
         m_SvnWrapper,SLOT(slotCheckoutCurrent()),m_filesAction,"make_svn_checkout_current");
     m_ExportCurrentAction = new KAction(i18n("Export current repository path"),"kdesvnexport",KShortcut(),
         m_SvnWrapper,SLOT(slotExportCurrent()),m_filesAction,"make_svn_export_current");
@@ -350,8 +368,8 @@ KURL::List kdesvnfilelist::selectedUrls()
     FileListViewItem*cur;
     while ( (cur=it.current())!=0) {
         ++it;
-        lst.append(cur->fullName());
-        kdDebug()<<"Appending " <<cur->fullName()<<endl;
+        /* for putting it to outside we must convert it to KIO urls */
+        lst.append(cur->kdeName(m_pList->m_remoteRevision));
     }
     return lst;
 }
@@ -374,6 +392,12 @@ SvnItem*kdesvnfilelist::Selected()
     return singleSelected();
 }
 
+void kdesvnfilelist::_openURL(const QString&url)
+{
+    openURL(url,true);
+    emit sigUrlChanged(baseUri());
+}
+
 bool kdesvnfilelist::openURL( const KURL &url,bool noReinit )
 {
     m_SvnWrapper->killallThreads();
@@ -518,7 +542,9 @@ bool kdesvnfilelist::checkDirs(const QString&_what,FileListViewItem * _parent)
         checkUnversionedDirs(_parent);
         return true;
     }
-
+    svn::StatusEntries neweritems;
+    m_SvnWrapper->getaddedItems(what,neweritems);
+    dlist+=neweritems;
     kdDebug() << "makeStatus on " << what << " created: " << dlist.count() << "items" <<endl;
 
     viewport()->setUpdatesEnabled(false);
@@ -526,7 +552,7 @@ bool kdesvnfilelist::checkDirs(const QString&_what,FileListViewItem * _parent)
     FileListViewItem * pitem = 0;
     bool main_found = false;
     for (;it!=dlist.end();++it) {
-        kdDebug() << "iterate over it: " << (*it).entry().url() << endl;
+        //kdDebug() << "iterate over it: " << (*it).entry().url() << endl;
 
         // current item is not versioned
         if (!(*it).isVersioned()) {
@@ -560,14 +586,19 @@ bool kdesvnfilelist::checkDirs(const QString&_what,FileListViewItem * _parent)
 void kdesvnfilelist::insertDirs(FileListViewItem * _parent,svn::StatusEntries&dlist)
 {
     svn::StatusEntries::iterator it;
+#if 0
+    KFileItemList oneItem;
+#endif
+
     for (it = dlist.begin();it!=dlist.end();++it) {
         FileListViewItem * item;
         if (!_parent) {
             item = new FileListViewItem(this,*it);
-//            kdDebug()<< "creating new FileListViewitem " + item->fullName() << endl;
         } else {
+            if ( (item = _parent->findChild( (*it).path() ))  ) {
+                delete item;
+            }
             item = new FileListViewItem(this,_parent,*it);
-//            kdDebug()<< "creating new FileListViewitem (with parent) " + item->fullName() << endl;
         }
         if (item->isDir()) {
             m_Dirsread[item->fullName()]=false;
@@ -575,12 +606,27 @@ void kdesvnfilelist::insertDirs(FileListViewItem * _parent,svn::StatusEntries&dl
             if (isWorkingCopy()) {
                 m_pList->m_DirWatch->addDir(item->fullName());
             }
-//            kdDebug()<< "Watching folder: " + item->fullName() << endl;
+            kdDebug()<< "Watching folder: " + item->fullName() << endl;
         } else if (isWorkingCopy()) {
             m_pList->m_DirWatch->addFile(item->fullName());
+#if 0
+            if (item->fileItem()) {
+                oneItem.append(item->fileItem());
+            }
+#endif
 //            kdDebug()<< "Watching file: " + item->fullName() << endl;
         }
     }
+#if 0
+    if (oneItem.count()>0) {
+        int size = Settings::listview_icon_size();
+        KIO::PreviewJob* m_previewJob= KIO::filePreview(oneItem, size, size, size, 70, true, true, 0);
+        connect( m_previewJob, SIGNAL( gotPreview( const KFileItem *, const QPixmap & ) ),
+                 this, SLOT( gotPreview( const KFileItem *, const QPixmap & ) ) );
+        connect( m_previewJob, SIGNAL( result( KIO::Job * ) ),
+                 this, SLOT( gotPreviewResult() ) );
+    }
+#endif
 }
 
 /* newdir is the NEW directory! just required if local */
@@ -704,6 +750,11 @@ void kdesvnfilelist::enableActions()
     /* 1. actions on dirs AND files */
     m_LogRangeAction->setEnabled(single||none);
     m_LogFullAction->setEnabled(single||none);
+    temp = filesActions()->action("make_svn_tree");
+    if (temp) {
+        temp->setEnabled(single||none);
+    }
+
     m_propertyAction->setEnabled(single);
     m_DelCurrent->setEnabled( (multi||single));
     m_LockAction->setEnabled( (multi||single));
@@ -735,11 +786,14 @@ void kdesvnfilelist::enableActions()
     m_ResolvedAction->setEnabled( (multi||single) && isWorkingCopy());
     m_InfoAction->setEnabled(isopen);
     m_MergeRevisionAction->setEnabled(single&&isWorkingCopy());
+    temp = filesActions()->action("make_svn_merge");
+    if (temp) {
+        temp->setEnabled(single);
+    }
     temp = filesActions()->action("make_svn_addrec");
     if (temp) {
         temp->setEnabled( (multi||single) && isWorkingCopy());
     }
-
     m_UpdateHead->setEnabled(isWorkingCopy()&&isopen);
     m_UpdateRev->setEnabled(isWorkingCopy()&&isopen);
     m_commitAction->setEnabled(isWorkingCopy()&&isopen);
@@ -753,7 +807,7 @@ void kdesvnfilelist::enableActions()
     m_CleanupAction->setEnabled(isWorkingCopy()&&dir);
     temp = filesActions()->action("make_check_unversioned");
     if (temp) {
-        temp->setEnabled(isWorkingCopy()&& (dir&&single) || none);
+        temp->setEnabled(isWorkingCopy()&& ((dir&&single) || none));
     }
 
     /* remote actions only */
@@ -841,10 +895,8 @@ void kdesvnfilelist::slotItemDoubleClicked(QListViewItem*item)
         }
         return;
     }
-    QString what = fki->fullName();
-    if (!isWorkingCopy()) {
-        what="ksvn+"+what;
-    }
+    svn::Revision rev(isWorkingCopy()?svn::Revision::UNDEFINED:m_pList->m_remoteRevision);
+    QString what = fki->kdeName(rev).prettyURL();
     QString feditor = Settings::external_display();
     if ( feditor.compare("default") == 0 )
     {
@@ -878,6 +930,7 @@ void kdesvnfilelist::slotResolved()
     if (!which) return;
     m_SvnWrapper->slotResolved(which->fullName());
     which->refreshStatus(true);
+    slotRescanIcons(false);
 }
 
 template<class T> KDialogBase* kdesvnfilelist::createDialog(T**ptr,const QString&_head,bool OkCancel,const char*name)
@@ -991,9 +1044,6 @@ void kdesvnfilelist::refreshCurrentTree()
     m_pList->m_fileTip->setItem(0);
     kapp->processEvents();
     setUpdatesEnabled(false);
-    if (isWorkingCopy()) {
-        m_SvnWrapper->createModifiedCache(baseUri());
-    }
     if (item->fullName()==baseUri()) {
         if (!refreshItem(item)) {
             setUpdatesEnabled(true);
@@ -1005,6 +1055,13 @@ void kdesvnfilelist::refreshCurrentTree()
     } else {
         refreshRecursive(0);
     }
+    if (isWorkingCopy()) {
+        m_SvnWrapper->createModifiedCache(baseUri());
+        if (Settings::start_updates_check_on_open()) {
+             slotRescanIcons(true);
+        }
+    }
+
     setUpdatesEnabled(true);
     viewport()->repaint();
     m_pList->startScan();
@@ -1047,6 +1104,7 @@ void kdesvnfilelist::refreshRecursive(FileListViewItem*_parent,bool down)
     svn::StatusEntries dlist;
 
     if (!m_SvnWrapper->makeStatus(what,dlist,m_pList->m_remoteRevision)) {
+        kdDebug()<<"Fehler bei makestatus fuer "<<what <<endl;
         return;
     }
 
@@ -1129,7 +1187,7 @@ void kdesvnfilelist::refreshRecursive(FileListViewItem*_parent,bool down)
     }
 }
 
-void kdesvnfilelist::slotRightButton(QListViewItem *_item, const QPoint &, int)
+void kdesvnfilelist::slotContextMenuRequested(QListViewItem *_item, const QPoint &, int)
 {
     FileListViewItem*item = static_cast<FileListViewItem*>(_item);
     bool isopen = baseUri().length()>0;
@@ -1172,6 +1230,7 @@ void kdesvnfilelist::startDrag()
     QListViewItem * m_pressedItem = currentItem();
     QPixmap pixmap2;
     KURL::List urls = selectedUrls();
+    kdDebug() << urls << endl;
     bool pixmap0Invalid = !m_pressedItem->pixmap(0) || m_pressedItem->pixmap(0)->isNull();
     if (( urls.count() > 1 ) || (pixmap0Invalid)) {
       int iconSize = Settings::listview_icon_size();;
@@ -1181,28 +1240,22 @@ void kdesvnfilelist::startDrag()
           kdWarning() << "Could not find multiple pixmap" << endl;
       }
     }
-    /* for putting it to outside we must convert it to KIO urls */
-    KURL::List::iterator it = urls.begin();
-    KURL uri = baseUri();
-    kdDebug()<<"Base protocol: " << uri.protocol()<<endl;
-    QString nProto;
-    if (uri.protocol()=="file" && !isWorkingCopy()) {
-        nProto="ksvn+file";
-    } else if (uri.protocol()=="http") {
-        nProto="ksvn+http";
-    } else if (uri.protocol()=="https") {
-        nProto="ksvn+https";
-    } else if (uri.protocol()=="svn") {
-        nProto="ksvn";
-    } else if (uri.protocol()=="svn+ssh") {
-        nProto="ksvn+ssh";
-    }
-    if (!nProto.isEmpty()) {
+
+    KURLDrag *drag;
+    drag = new KURLDrag(urls,this);
+
+    /* workaround for KURL::Drag - it always forget the revision part on drop :( */
+    if (!isWorkingCopy()) {
+        QStrList l;
+        QString t;
+        KURL::List::ConstIterator it = urls.begin();
         for (;it!=urls.end();++it) {
-            (*it).setProtocol(nProto);
+            l.append((*it).prettyURL());
         }
+        drag->setUris(l);
     }
-    KURLDrag *drag= new KURLDrag(urls,this);
+
+    drag->setExportAsText(true);
     if ( !pixmap2.isNull() )
         drag->setPixmap( pixmap2 );
     else if ( !pixmap0Invalid )
@@ -1224,6 +1277,12 @@ bool kdesvnfilelist::acceptDrag(QDropEvent *event)const
 bool kdesvnfilelist::validDropEvent(QDropEvent*event,QListViewItem*&item)
 {
     if (!event) return false;
+    if (!isWorkingCopy()) {
+        if (m_pList->m_remoteRevision!=svn::Revision::HEAD) {
+            item = 0;
+            return false;
+        }
+    }
     bool ok = false;
     item = 0;
     if (KURLDrag::canDecode(event)) {
@@ -1265,7 +1324,7 @@ void kdesvnfilelist::contentsDragMoveEvent( QDragMoveEvent* event)
     QListViewItem * item;
     bool ok = validDropEvent(event,item);
 
-    if (item!=m_pList->dragOverItem) {
+    if (item && item!=m_pList->dragOverItem) {
         QPoint vp = contentsToViewport( event->pos() );
         m_pList->dragOverItem=item;
         m_pList->dragOverPoint = vp;
@@ -1323,6 +1382,53 @@ void kdesvnfilelist::slotMergeRevisions()
     refreshRecursive(which);
 }
 
+void kdesvnfilelist::slotMerge()
+{
+    FileListViewItem*which= singleSelected();
+    QString src1,src2,target;
+    if (which) {
+        if (isWorkingCopy()) {
+            target = which->fullName();
+        } else {
+            src1 = which->fullName();
+        }
+    }
+    bool force,dry,rec,irelated;
+    Rangeinput_impl::revision_range range;
+    MergeDlg_impl*ptr;
+    KDialogBase*dlg = createDialog(&ptr,QString(i18n("Merge")),true,"merge_dialog");
+    if (!dlg) {
+        return;
+    }
+
+    ptr->setDest(target);
+    ptr->setSrc1(src1);
+    ptr->setSrc2(src1);
+    if (dlg->exec()==QDialog::Accepted) {
+        src1=ptr->Src1();
+        src2=ptr->Src2();
+        if (src2.isEmpty()) {
+            src2 = src1;
+        }
+        target = ptr->Dest();
+        force = ptr->force();
+        dry = ptr->dryrun();
+        rec = ptr->recursive();
+        irelated = ptr->ignorerelated();
+        range = ptr->getRange();
+        m_SvnWrapper->slotMerge(src1,src2,target,range.first,range.second,rec,irelated,force,dry);
+        if (isWorkingCopy()) {
+//            refreshItem(which);
+//            refreshRecursive(which);
+            refreshCurrentTree();
+        }
+    }
+
+    dlg->saveDialogSize(*(Settings::self()->config()),"merge_dialog",false);
+
+    delete dlg;
+}
+
 void kdesvnfilelist::slotDropped(QDropEvent* event,QListViewItem*item)
 {
     KURL::List urlList;
@@ -1386,8 +1492,13 @@ void kdesvnfilelist::slotDropped(QDropEvent* event,QListViewItem*item)
             nProto = svn::Url::transformProtokoll(urlList[0].protocol());
         }
         KURL::List::Iterator it = urlList.begin();
+        QStringList l;
         for (;it!=urlList.end();++it) {
             (*it).setProtocol(nProto);
+            l = QStringList::split("?",(*it).prettyURL());
+            if (l.size()>1) {
+                (*it) = l[0];
+            }
         }
         event->acceptAction();
         m_pList->intern_dropRunning=true;
@@ -1421,8 +1532,11 @@ void kdesvnfilelist::slotInternalDrop()
             }
          }
     }
-    bool move = action==QDropEvent::Move;
-    m_SvnWrapper->slotCopyMove(move,m_pList->intern_drops,m_pList->intern_drop_target,false);
+    if (action==QDropEvent::Move) {
+        m_SvnWrapper->makeMove(m_pList->intern_drops,m_pList->intern_drop_target,false);
+    } else {
+        m_SvnWrapper->makeCopy(m_pList->intern_drops,m_pList->intern_drop_target,svn::Revision::HEAD);
+    }
     m_pList->intern_dropRunning=false;
     refreshCurrentTree();
 }
@@ -1452,14 +1566,19 @@ void kdesvnfilelist::copy_move(bool move)
     if (!ok) {
         return;
     }
-    m_SvnWrapper->slotCopyMove(move,which->fullName(),nName,force);
+    if (move) {
+        m_SvnWrapper->makeMove(which->fullName(),nName,force);
+    } else {
+        m_SvnWrapper->makeCopy(which->fullName(),nName, isWorkingCopy()?svn::Revision::HEAD:m_pList->m_remoteRevision);
+    }
 }
 
 void kdesvnfilelist::slotCat()
 {
     FileListViewItem*k = singleSelected();
     if (!k) return;
-    m_SvnWrapper->makeCat(isWorkingCopy()?svn::Revision::HEAD:m_pList->m_remoteRevision, k->fullName(),k->text(0));
+    m_SvnWrapper->makeCat(isWorkingCopy()?svn::Revision::HEAD:m_pList->m_remoteRevision, k->fullName(),k->text(0),
+        isWorkingCopy()?svn::Revision::HEAD:m_pList->m_remoteRevision);
 }
 
 
@@ -1519,7 +1638,8 @@ void kdesvnfilelist::slotDelete()
     while ((cur=liter.current())!=0){
         ++liter;
         if (!cur->isRealVersioned()) {
-            kioList.append(cur->fullName());
+            KURL _uri; _uri.setPath(cur->fullName());
+            kioList.append(_uri);
         } else {
             items.push_back(cur->fullName());
         }
@@ -1591,7 +1711,7 @@ void kdesvnfilelist::slotLock()
     dlg = createDialog(&ptr,QString(i18n("Lock message")),true,"locking_log_msg");
     if (!dlg) return;
     ptr->initHistory();
-    ptr->setRecCheckboxtext(i18n("Steal lock?"));
+    ptr->setRecCheckboxtext(i18n("Steal lock?"),false);
 
     if (dlg->exec()!=QDialog::Accepted) {
         delete dlg;
@@ -1843,11 +1963,8 @@ bool kdesvnfilelist::refreshItem(FileListViewItem*item)
 void kdesvnfilelist::slotCheckUpdates()
 {
     m_SvnWrapper->createUpdateCache(baseUri());
-    //reinitItems(0);
-    //rescanIconsRec(0L);
 }
 
-
 /*!
     \fn kdesvnfilelist::reinitItems(FileListViewItem*_item = 0)
  */
@@ -1878,21 +1995,19 @@ void kdesvnfilelist::slotInfo()
 {
     QPtrList<SvnItem> lst;
     SelectionList(&lst);
-    svn::Revision peg(svn_opt_revision_unspecified);
-    svn::Revision rev(svn_opt_revision_unspecified);
+    svn::Revision rev(isWorkingCopy()?svn::Revision::UNDEFINED:m_pList->m_remoteRevision);
     if (!isWorkingCopy()) {
         rev = m_pList->m_remoteRevision;
     }
     if (lst.count()==0) {
         if (!isWorkingCopy()) {
-            QStringList l; l.append(baseUri());
-            m_SvnWrapper->makeInfo(l,rev,peg,Settings::info_recursive());
+            m_SvnWrapper->makeInfo(baseUri(),rev,svn::Revision::UNDEFINED,Settings::info_recursive());
         } else {
             lst.append(SelectedOrMain());
         }
     }
     if (lst.count()>0) {
-        m_SvnWrapper->makeInfo(lst,rev,peg,Settings::info_recursive());
+        m_SvnWrapper->makeInfo(lst,rev,svn::Revision::UNDEFINED,Settings::info_recursive());
     }
 }
 
@@ -1974,6 +2089,26 @@ void kdesvnfilelist::slotDirItemDeleted(const QString&what)
     m_pList->startScan();
 }
 
+
+void kdesvnfilelist::gotPreview( const KFileItem*, const QPixmap&)
+{
+#if 0
+    FileListViewItem*which = findEntryItem(item->localPath());
+    if (which) {
+        which->setPreviewPix(pixmap);
+    }
+//    m_previewJob = 0;
+//    if (m_svnitem || item != m_svnitem->fileItem()) return;
+
+//    m_iconLabel -> setPixmap(pixmap);
+#endif
+}
+
+void kdesvnfilelist::gotPreviewResult()
+{
+//    m_previewJob = 0;
+}
+
 FileListViewItem* kdesvnfilelist::findEntryItem(const QString&what,FileListViewItem*startAt)
 {
     if (!startAt && !what.startsWith(baseUri())) return 0;
@@ -2018,7 +2153,7 @@ void kdesvnfilelist::contentsMouseMoveEvent( QMouseEvent *e )
             vp.setY( itemRect( item ).y() );
             QRect rect( viewportToContents( vp ), QSize(20, item->height()) );
             m_pList->m_fileTip->setItem( static_cast<SvnItem*>(item), rect, item->pixmap(0));
-            m_pList->m_fileTip->setPreview(KGlobalSettings::showFilePreview(item->fullName())&&isWorkingCopy()
+            m_pList->m_fileTip->setPreview(KGlobalSettings::showFilePreview(item->fullName())/*&&isWorkingCopy()*/
                 &&Settings::display_previews_in_file_tips());
             setShowToolTips(false);
         } else {
@@ -2163,9 +2298,9 @@ void kdesvnfilelist::checkUnversionedDirs( FileListViewItem * _parent )
     //this->insertDirs(_parent, nonversioned_list);
 }
 
-void kdesvnfilelist::rescanIconsRec(FileListViewItem*startAt)
+void kdesvnfilelist::rescanIconsRec(FileListViewItem*startAt,bool checkNewer)
 {
-    FileListViewItem*_s,*_temp;
+    FileListViewItem*_s;
     if (!startAt) {
         _s = static_cast<FileListViewItem*>(firstChild());
     } else {
@@ -2174,16 +2309,28 @@ void kdesvnfilelist::rescanIconsRec(FileListViewItem*startAt)
     if (!_s) {
         return;
     }
+    svn::Status d;
     while (_s) {
-        _s->makePixmap();
-        rescanIconsRec(_s);
+        //_s->makePixmap();
+        if (m_SvnWrapper->getUpdated(_s->stat().path(),d)) {
+            _s->updateStatus(d);
+        } else {
+            _s->update();
+        }
+        rescanIconsRec(_s,checkNewer);
+        if (checkNewer && _s->isDir() && _s->isOpen()) {
+            svn::StatusEntries target;
+            kdDebug( ) << "Checking added items for " << _s->stat().path()<< " Revision: " << _s->stat().entry().revision() << endl;
+            m_SvnWrapper->getaddedItems(_s->stat().path(),target);
+            insertDirs(_s,target);
+        }
         _s = static_cast<FileListViewItem*>(_s->nextSibling());
     }
 }
 
-void kdesvnfilelist::slotRescanIcons()
+void kdesvnfilelist::slotRescanIcons(bool checkNewer)
 {
-    rescanIconsRec(0L);
+    rescanIconsRec(0L,checkNewer);
 }
 
 
@@ -2237,6 +2384,22 @@ void kdesvnfilelist::slotMakeRangeLog()
 }
 
 
+void kdesvnfilelist::slotMakeTree()
+{
+    QString what;
+    SvnItem*k = SelectedOrMain();
+    if (k) {
+        what = k->fullName();
+    } else if (!isWorkingCopy() && allSelected()->count()==0){
+        what = baseUri();
+    } else {
+        return;
+    }
+    svn::Revision rev(isWorkingCopy()?svn::Revision::WORKING:m_pList->m_remoteRevision);
+
+    m_SvnWrapper->makeTree(what,rev);
+}
+
 /*!
     \fn kdesvnfilelist::slotMakeLog()
  */
@@ -2254,10 +2417,18 @@ void kdesvnfilelist::slotMakeLog()
     // yes! so if we have a limit, the limit counts from HEAD
     // not from START
     svn::Revision start(svn::Revision::HEAD);
+    if (!isWorkingCopy()) {
+        start=m_pList->m_remoteRevision;
+    }
     svn::Revision end(svn::Revision::START);
     bool list = Settings::self()->log_always_list_changed_files();
     int l = Settings::self()->maximum_displayed_logs();
     m_SvnWrapper->makeLog(start,end,what,list,l);
 }
 
+const svn::Revision& kdesvnfilelist::remoteRevision()const
+{
+    return m_pList->m_remoteRevision;
+}
+
 #include "kdesvnfilelist.moc"
