@@ -22,7 +22,7 @@
 #include "svnactions.h"
 #include "kdesvn_part.h"
 #include "fronthelpers/settings.h"
-#include "svncpp/status.hpp"
+#include "svnqt/status.hpp"
 #include "helpers/smart_pointer.h"
 #include "helpers/sub2qt.h"
 
@@ -38,6 +38,8 @@
 #include <qfileinfo.h>
 #include <qimage.h>
 #include <qptrlist.h>
+#include <qpainter.h>
+#include <qbitmap.h>
 
 class SvnItem_p:public ref_count
 {
@@ -46,14 +48,19 @@ public:
     SvnItem_p();
     SvnItem_p(const svn::Status&);
     virtual ~SvnItem_p();
+    KFileItem*createItem(const svn::Revision&peg);
+    const KURL& kdeName(const svn::Revision&);
+
 protected:
     svn::Status m_Stat;
     void init();
     QString m_url,m_full,m_short;
+    KURL m_kdename;
     QDateTime m_fullDate;
     QString m_infoText;
     KFileItem*m_fitem;
     bool isWc;
+    svn::Revision lRev;
 };
 
 SvnItem_p::SvnItem_p()
@@ -76,6 +83,8 @@ SvnItem_p::~SvnItem_p()
 void SvnItem_p::init()
 {
     m_full = m_Stat.path();
+    m_kdename="";
+    lRev=svn::Revision::UNDEFINED;
     while (m_full.endsWith("/")) {
         /* dir name possible */
         m_full.truncate(m_full.length()-1);
@@ -90,12 +99,64 @@ void SvnItem_p::init()
     m_url = m_Stat.entry().url();
     m_fullDate = helpers::sub2qt::apr_time2qt(m_Stat.entry().cmtDate());
     m_infoText = QString::null;
+    m_fitem = 0;
+}
+
+const KURL& SvnItem_p::kdeName(const svn::Revision&r)
+{
     isWc = QString::compare(m_Stat.entry().url(),m_Stat.path())!=0;
-    if (!isWc) {
-        m_fitem=0;
-    } else {
-        m_fitem = new KFileItem(KFileItem::Unknown,KFileItem::Unknown,m_Stat.path());
+    QString name;
+    if (!(r==lRev)||m_kdename.isEmpty()) {
+        lRev=r;
+        if (!isWc) {
+            QString ouri =m_Stat.entry().url();
+            QString proto;
+            QStringList l=QStringList::split(":",ouri);
+            if (ouri.startsWith("svn://")){
+                proto = "ksvn";
+            } else if (ouri.startsWith("svn+ssh://")){
+                proto = "ksvn+ssh";
+            } else {
+                proto = "ksvn+"+l[0];
+            }
+            m_kdename.setProtocol(proto);
+            l = QStringList::split("://",ouri);
+            if (proto=="ksvn+file") {
+                if (l.size()>1) {
+                    m_kdename.setPath(l[1]);
+                }
+            } else if (l.size()>1){
+                l=QStringList::split("/",l[1]);
+                m_kdename.setHost(l[0]);
+                l.remove(l.begin());
+                m_kdename.setPath("/"+l.join("/"));
+            }
+
+            QString revstr="";
+            if (lRev.kind()==svn::Revision::HEAD) {
+                revstr="HEAD";
+            } else if (lRev.kind()==svn_opt_revision_number) {
+                revstr=QString("%1").arg(lRev.revnum());
+            } else if (lRev.kind()==svn_opt_revision_date) {
+                QDateTime t = helpers::sub2qt::apr_time2qt(lRev.date());
+                revstr=QString("{%1}").arg(t.toString("yyyy-MM-dd"));
+            }
+            m_kdename.setQuery("?rev="+revstr);
+        } else {
+            m_kdename.setPath(m_Stat.path());
+        }
     }
+    return m_kdename;
+}
+
+KFileItem*SvnItem_p::createItem(const svn::Revision&peg)
+{
+    if (!m_fitem||!(peg==lRev) ) {
+        delete m_fitem;
+        m_fitem=0;
+        m_fitem=new KFileItem(KFileItem::Unknown,KFileItem::Unknown,kdeName(peg));
+    }
+    return m_fitem;
 }
 
 SvnItem::SvnItem()
@@ -137,7 +198,7 @@ const QString&SvnItem::Url()const
 
 bool SvnItem::isDir()const
 {
-    if (p_Item->m_Stat.entry().isValid()) {
+    if (isRemoteAdded() || p_Item->m_Stat.entry().isValid()) {
         return p_Item->m_Stat.entry().kind()==svn_node_dir;
     }
     /* must be a local file */
@@ -150,6 +211,99 @@ const QDateTime&SvnItem::fullDate()const
     return (p_Item->m_fullDate);
 }
 
+QPixmap SvnItem::internalTransform(const QPixmap&first,int size)
+{
+    QPixmap result(size,size);
+    if (result.isNull()) {
+        return result;
+    }
+    const QBitmap * b = first.mask();
+    result.fill(Qt::white);
+    if (b) {
+        result.setMask(*b);
+    } else {
+        QBitmap m(size,size,true);
+        m.fill(Qt::white);
+        result.setMask(m);
+    }
+    QPainter pa;
+    pa.begin(&result);
+    int w = first.width()>size?size:first.width();
+    int h = first.height()>size?size:first.height();
+    pa.drawPixmap(0,0,first,0,0,w,h);
+    pa.end();
+    return result;
+}
+
+QPixmap SvnItem::getPixmap(const QPixmap&_p,int size,bool overlay)
+{
+    QPixmap p;
+    if (_p.width()!=size || _p.height()!=size) {
+         p = internalTransform(_p,size);
+    } else {
+        p = _p;
+    }
+
+//    if (QString::compare(p_Item->m_Stat.entry().url(),p_Item->m_Stat.path())!=0) {
+        if (!isVersioned()) {
+            m_bgColor = NOTVERSIONED;
+        } else if (isRealVersioned()) {
+            SvnActions*wrap = getWrapper();
+            bool mod = false;
+            QPixmap p2 = QPixmap();
+            if (p_Item->m_Stat.textStatus ()==svn_wc_status_conflicted) {
+                m_bgColor = CONFLICT;
+                if (overlay)
+                    p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnconflicted",KIcon::Desktop,size);
+            } else if (p_Item->m_Stat.textStatus ()==svn_wc_status_missing) {
+                m_bgColor = MISSING;
+            } else if (isLocked()||wrap->checkReposLockCache(fullName())) {
+                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnlocked",KIcon::Desktop,size);
+                m_bgColor = LOCKED;
+            } else if (!isRemoteAdded() && wrap->isLockNeeded(this,svn::Revision::UNDEFINED) ) {
+                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnneedlock",KIcon::Desktop,size);
+                m_bgColor = NEEDLOCK;
+            } else if (wrap->isUpdated(p_Item->m_Stat.path())) {
+                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnupdates",KIcon::Desktop,size);
+                m_bgColor = UPDATES;
+            } else if (p_Item->m_Stat.textStatus()==svn_wc_status_deleted) {
+                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvndeleted",KIcon::Desktop,size);
+                m_bgColor = DELETED;
+            } else if (p_Item->m_Stat.textStatus()==svn_wc_status_added ) {
+                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnadded",KIcon::Desktop,size);
+                m_bgColor = ADDED;
+            } else if (isModified()) {
+                mod = true;
+            } else if (isDir()&&wrap) {
+                svn::StatusEntries dlist;
+                svn::StatusEntries::const_iterator it;
+                if (isRemoteAdded() || wrap->checkUpdateCache(fullName())) {
+                    if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnupdates",KIcon::Desktop,size);
+                    m_bgColor = UPDATES;
+                } else if (wrap->checkConflictedCache(fullName())) {
+                    m_bgColor = CONFLICT;
+                    if (overlay)
+                        p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnconflicted",KIcon::Desktop,size);
+                } else {
+                    mod = wrap->checkModifiedCache(fullName());
+                }
+            }
+            if (mod) {
+                m_bgColor = MODIFIED;
+                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnmodified",KIcon::Desktop,size);
+            }
+            if (!p2.isNull()) {
+                m_overlaycolor = true;
+                QImage i1; i1 = p;
+                QImage i2;i2 = p2;
+
+                KIconEffect::overlay(i1,i2);
+                p = i1;
+            }
+        }
+//    }
+    return p;
+}
 
 QPixmap SvnItem::getPixmap(int size,bool overlay)
 {
@@ -168,65 +322,31 @@ QPixmap SvnItem::getPixmap(int size,bool overlay)
             p = kdesvnPartFactory::instance()->iconLoader()->loadIcon("unknown",KIcon::Desktop,size);
         }
         if (isLocked()) {
-            QPixmap p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnlocked",KIcon::Desktop,size);
-            QImage i1; i1 = p;
-            QImage i2; i2 = p2;
-            KIconEffect::overlay(i1,i2);
-            p = i1;
+            m_bgColor = LOCKED;
+            QPixmap p2;
+            if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnlocked",KIcon::Desktop,size);
+            if (!p2.isNull()) {
+            	QImage i1; i1 = p;
+            	QImage i2; i2 = p2;
+            	KIconEffect::overlay(i1,i2);
+            	p = i1;
+            }
         }
     } else {
         _local = true;
-        p = KMimeType::pixmapForURL(fullName(),0,KIcon::Desktop,size);
-    }
-    if (overlay && _local && isRealVersioned()) {
-        SvnActions*wrap = getWrapper();
-        bool mod = false;
-        QPixmap p2 = QPixmap();
-        if (isLocked()) {
-            p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnlocked",KIcon::Desktop,size);
-            m_bgColor = LOCKED;
-        } else if (wrap->isUpdated(p_Item->m_Stat.path())) {
-            p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnupdates",KIcon::Desktop,size);
-            m_bgColor = UPDATES;
-        } else if (p_Item->m_Stat.textStatus()==svn_wc_status_deleted) {
-            p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvndeleted",KIcon::Desktop,size);
-            m_bgColor = DELETED;
-        } else if (p_Item->m_Stat.textStatus()==svn_wc_status_added ) {
-            p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnadded",KIcon::Desktop,size);
-            m_bgColor = ADDED;
-        } else if (isModified()) {
-            mod = true;
-        } else if (isDir()&&wrap) {
-            svn::StatusEntries dlist;
-            svn::StatusEntries::const_iterator it;
-            wrap->checkUpdateCache(fullName(),dlist);
-            if (dlist.size()>0) {
-                p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnupdates",KIcon::Desktop,size);
-                m_bgColor = UPDATES;
+        if (isRemoteAdded()) {
+            kdDebug()<<"Remoteadded"<<endl;
+            if (isDir()) {
+                kdDebug()<<"Remotedir"<<endl;
+                p = kdesvnPartFactory::instance()->iconLoader()->loadIcon("folder",KIcon::Desktop,size);
             } else {
-                wrap->checkModifiedCache(fullName(),dlist);
-                for (it=dlist.begin();it!=dlist.end();++it) {
-                    if ( (*it).textStatus()==svn_wc_status_modified||
-                        (*it).textStatus()==svn_wc_status_added||
-                        (*it).textStatus()==svn_wc_status_deleted||
-                        (*it).textStatus()==svn_wc_status_conflicted ||
-                        (*it).propStatus()==svn_wc_status_modified) {
-                        mod = true;
-                        break;
-                    }
-                }
+                p = kdesvnPartFactory::instance()->iconLoader()->loadIcon("unknown",KIcon::Desktop,size);
             }
-        }
-        if (mod) {
-            m_bgColor = MODIFIED;
-            p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnmodified",KIcon::Desktop,size);
-        }
-        if (!p2.isNull()) {
-            m_overlaycolor = true;
-            QImage i1; i1 = p;
-            QImage i2; i2 = p2;
-            KIconEffect::overlay(i1,i2);
-            p = i1;
+        } else {
+            KURL uri;
+            uri.setPath(fullName());
+            p = KMimeType::pixmapForURL(uri,0,KIcon::Desktop,size);
+            p = getPixmap(p,size,overlay);
         }
     }
     return p;
@@ -256,11 +376,21 @@ bool SvnItem::isIgnored()const
     return p_Item->m_Stat.textStatus()==svn_wc_status_ignored;
 }
 
+bool SvnItem::isRemoteAdded()const
+{
+    return getWrapper()->isUpdated(p_Item->m_Stat.path()) &&
+            p_Item->m_Stat.validReposStatus()&&!p_Item->m_Stat.validLocalStatus();
+}
+
 QString SvnItem::infoText()const
 {
     QString info_text = "";
     if (getWrapper()->isUpdated(p_Item->m_Stat.path())) {
-        info_text = i18n("Needs update");
+        if (p_Item->m_Stat.validReposStatus()&&!p_Item->m_Stat.validLocalStatus()) {
+            info_text = i18n("Added in repository");
+        } else {
+            info_text = i18n("Needs update");
+        }
     } else {
     switch(p_Item->m_Stat.textStatus ()) {
     case svn_wc_status_modified:
@@ -326,7 +456,14 @@ bool SvnItem::isLocked()const
 
 QString SvnItem::lockOwner()const
 {
-    return p_Item->m_Stat.entry().lockEntry().Owner();
+    if (p_Item->m_Stat.entry().lockEntry().Locked()) {
+        return p_Item->m_Stat.entry().lockEntry().Owner();
+    }
+    svn::Status tmp;
+    if (getWrapper()->checkReposLockCache(fullName(),tmp)) {
+        return tmp.lockEntry().Owner();
+    }
+    return "";
 }
 
 
@@ -359,13 +496,14 @@ bool SvnItem::isNormal()const
 const QString& SvnItem::getToolTipText()
 {
     if (p_Item->m_infoText.isNull()) {
-        if (isRealVersioned()) {
+        if (isRealVersioned() && !p_Item->m_Stat.entry().url().isEmpty()) {
             SvnActions*wrap = getWrapper();
             svn::Revision peg(svn_opt_revision_unspecified);
             svn::Revision rev(svn_opt_revision_unspecified);
             if (QString::compare(p_Item->m_Stat.entry().url(),p_Item->m_Stat.path())==0) {
                 /* remote */
-                rev = svn::Revision::HEAD;
+                rev = p_Item->m_Stat.entry().revision();
+                peg = correctPeg();
             } else {
                 /* local */
             }
@@ -383,5 +521,10 @@ const QString& SvnItem::getToolTipText()
 
 KFileItem*SvnItem::fileItem()
 {
-    return p_Item->m_fitem;
+    return p_Item->createItem(correctPeg());
+}
+
+const KURL&SvnItem::kdeName(const svn::Revision&r)
+{
+    return p_Item->kdeName(r);
 }
