@@ -20,7 +20,7 @@
 #ifndef THREADCONTEXTLISTENERDATA_H
 #define THREADCONTEXTLISTENERDATA_H
 
-#include "svncpp/context_listener.hpp"
+#include "svnqt/context_listener.hpp"
 
 #include <qthread.h>
 #include <qstring.h>
@@ -58,6 +58,8 @@ public:
     {
         QString msg;
         bool ok;
+        const svn::CommitItemList*_items;
+        slog_message(){_items = 0;}
     };
 
     struct scert_pw
